/************************************************************
File name: 0_hostCodegenerator.sv

					CODE GENERATOR FOR HOST
					
************************************************************/
	reg	[5:0]	opCode			;
	reg	[4:0]	dest			;
	reg	[4:0]	left			;
	reg	[4:0]	right			;
	reg	[15:0]	value			;
	reg [9:0] 	addrCounter 	;
	reg [9:0] 	labelTab[0:1023];
	
	`include "0_DEFINES.vh"
	
	function endLine;
		dut.HOST.hostProgramMemory.hPmem[addrCounter][31:0] = 
			{	opCode	,	
				dest	,
				left	,
				value	}					;
			addrCounter	= addrCounter + 1	;
	endfunction

	// sets labelTab in the first pass 
	// associating 'counter' with 'labelIndex'
	function hLB(input logic [5:0] labelIndex); 
		labelTab[labelIndex] = addrCounter; 
	endfunction
	
	// uses the content of labelTab in the second pass
	function hULB(input logic [5:0] labelIndex); 
		value = labelTab[labelIndex] - addrCounter;	
	endfunction
	
	`include "cgHOST_LIBRARY.sv"

// CONTROL INSTRUCTIONS
	function hNOP; 
	
		opCode	= `hnop	;
		dest	= 5'b0	;
		left	= 5'b0	;
		value	= 16'b0	;	
		endLine			;
	endfunction
	
	function hJMP(input	logic [15:0] label)	;
	
		opCode	= `hjmp	;
		dest	= 5'b0	;
		left	= 5'b0	;
		hULB(label)		;	
		endLine			;
	endfunction
	
	function hJMPZ(	input logic [4:0] regfile	,
					input logic [9:0] label		);
					
		opCode	= `hjmpz	;
		dest	= 5'b0		;
		left	= regfile	;
		hULB(label)			;	
		endLine				;
	endfunction
	
	function hJMPNZ(input logic [4:0] regfile	,
					input logic [9:0] label		);
		
		opCode	= `hjmpnz	;
		dest	= 5'b0		;
		left	= regfile	;
		hULB(label)			;	
		endLine				;
	endfunction
	
	function hPSEND(input logic [4:0] d	,
					input logic [4:0] l	);
		
		opCode	= `hpsend	;
		dest	= d			;
		left	= l			;
		value	= 16'b0		;	
		endLine				;
	endfunction
	
	function hDGET(	input logic [4:0] d	,
					input logic [4:0] l	, 	// initial address
					input logic [4:0] r	); 	// final address
		
		opCode	= `hdget	;
		dest	= d			;
		left	= l			;
		value	= {r, 11'b0};	
		endLine				;
	endfunction
	
	function hDSEND(input logic [4:0] d	,
					input logic [4:0] l	, 	// initial address
					input logic [4:0] r	); 	// final address
		
		opCode	= `hdsend	;
		dest	= d			;
		left	= l			;
		value	= {r, 11'b0};
		endLine				;
	endfunction
	
	//function hFSEND;
	//	
	//	begin 	opCode	= `hfsend	;
	//			dest	= 5'b0		;
	//			left	= 5'b0		;
	//			value	= 16'b0		;
	//			endLine				;
	//	end
	//endfunction
	//
	//function hSSEND; 
	//	input	[26:0] scalar;
	//	
	//	begin 	opCode	= `hssend			;
	//			{dest, left, value} = scalar;
	//			endLine						;
	//	end
	//endfunction
	
	function hINTWAIT; 
		opCode	= `hintwait	;
		dest	= 5'b0		;
		left	= 5'b0		;
		value	= 16'b0		;	
		endLine				;
	endfunction
	
	function hAJMP(input logic [15:0] scalar);
		
		opCode	= `hajmp;
		dest	= 5'b0	;
		left	= 5'b0	;
		value	= scalar;	
		endLine			;
	endfunction
	
	function hHALT; 
		opCode	= `hhalt;
		dest	= 5'b0	;
		left	= 5'b0	;
		value	= 16'b0	;	
		endLine			;
	endfunction
	
	function hSTARTCC; 
		opCode	= `hsttcc	;
		dest	= 5'b0		;
		left	= 5'b0		;
		value	= 16'b0		;	
		endLine				;
	endfunction
	
	function hSTOPCC; 
		opCode	= `hstpcc	;
		dest	= 5'b0		;
		left	= 5'b0		;
		value	= 16'b0		;	
		endLine				;
	endfunction
	
// FUNCTIONAL INSTRUCTIONS
	function hADD(	input logic [4:0] d	,
					input logic [4:0] l	,
					input logic [4:0] r	);
		
		opCode	= `hadd		;
		dest	= d			;
		left	= l			;
		value	= {r, 11'b0};	
		endLine				;
	endfunction
	
	function hADDCR(input logic [4:0] d	,
					input logic [4:0] l	,
					input logic [4:0] r	);
		
		begin 	opCode	= `haddcr	;
				dest	= d			;
				left	= l			;
				value	= {r, 11'b0};	
				endLine				;
		end
	endfunction
	
	function hSUB(	input logic [4:0] d	,
					input logic [4:0] l	,
					input logic [4:0] r	);
		
		opCode	= `hsub		;
		dest	= d			;
		left	= l			;
		value	= {r, 11'b0};	
		endLine				;
	endfunction
	
	function hSUBCR(input logic [4:0] d	,
					input logic [4:0] l	,
					input logic [4:0] r	);
		
		opCode	= `hsubcr	;
		dest	= d			;
		left	= l			;
		value	= {r, 11'b0};	
		endLine				;
	endfunction
	
	function hMULT(	input logic [4:0] d	,
					input logic [4:0] l	,
					input logic [4:0] r	);
		
		opCode	= `hmult	;
		dest	= d			;
		left	= l			;
		value	= {r, 11'b0};	
		endLine				;
	endfunction
	
	function hAND(	input logic [4:0] d	,
					input logic [4:0] l	,
					input logic [4:0] r	);
		
		opCode	= `hbwand	;
		dest	= d			;
		left	= l			;
		value	= {r, 11'b0};	
		endLine				;
	endfunction
	
	function hOR(	input logic [4:0] d	,
					input logic [4:0] l	,
					input logic [4:0] r	);
		
		opCode	= `hbwor	;
		dest	= d			;
		left	= l			;
		value	= {r, 11'b0};	
		endLine				;
	endfunction
	
	function hXOR(	input logic [4:0] d	,
					input logic [4:0] l	,
					input logic [4:0] r	);
		
		opCode	= `hbwxor	;
		dest	= d			;
		left	= l			;
		value	= {r, 11'b0};	
		endLine				;
	endfunction
	
	function hADDV(	input logic [4:0] 	d		,
					input logic [4:0] 	l		,
					input logic [15:0]	scalar	);
		
		opCode	= `haddv;
		dest	= d		;
		left	= l		;
		value	= scalar;
		endLine			;
	endfunction
	
	function hADDCRV(	input logic [4:0]	d		,
						input logic [4:0]	l		,
						input logic [15:0]	scalar	);
		
		opCode	= `haddcrv	;
		dest	= d			;
		left	= l			;
		value	= scalar	;	
		endLine				;
	endfunction
	
	function hSUBV(	input logic [4:0]	d		,
					input logic [4:0]	l		,
					input logic [15:0]	scalar	);
		
		opCode	= `hsubv;
		dest	= d		;
		left	= l		;
		value	= scalar;
		endLine			;
	endfunction
	
	function hSUBCRV(	input logic [4:0]	d		,
						input logic [4:0]	l		,
						input logic [15:0]	scalar	);
		
		opCode	= `hsubcrv	;
		dest	= d			;
		left	= l			;
		value	= scalar	;	
		endLine				;
	endfunction
	
	function hMULTV(input logic [4:0]	d		,
					input logic [4:0]	l		,
					input logic [15:0]	scalar	);
		
		opCode	= `hmultv	;
		dest	= d			;
		left	= l			;
		value	= scalar	;
		endLine				;
	endfunction
	
	function hANDV(	input logic [4:0]	d		,
					input logic [4:0]	l		,
					input logic [15:0]	scalar	);
		
		opCode	= `hbwandv	;
		dest	= d			;
		left	= l			;
		value	= scalar	;	
		endLine				;
	endfunction
	
	function hORV(	input logic [4:0]	d		,
					input logic [4:0]	l		,
					input logic [15:0]	scalar	);
		
		opCode	= `hbworv	;
		dest	= d			;
		left	= l			;
		value	= scalar	;
		endLine				;
	endfunction
	
	function hXORV(	input logic [4:0]	d		,
					input logic [4:0]	l		,
					input logic [15:0]	scalar	);
		
		opCode	= `hbwxorv	;
		dest	= d			;
		left	= l			;
		value	= scalar	;	
		endLine				;
	endfunction

// DATA TRANSFER INSTRUCTIONS
	function hVALUE(input logic [4:0]	d		,
					input logic [15:0]	scalar	);
		
		opCode	= `hvalue	;
		dest	= d			;
		left	= 5'b0		;
		value	= scalar	;	
		endLine				;
	endfunction
	
	function hINSVAL(input logic [4:0]	d		,
					input logic [15:0]	scalar	);
		
		opCode	= `hinsval	;
		dest	= d			;
		left	= 5'b0		;
		value	= scalar	;	
		endLine				;
	endfunction
	
	function hLOAD(	input logic [4:0] d	,
					input logic [4:0] l	);
		
		opCode	= `hload;
		dest	= d		;
		left	= l		;
		value	= 16'b0	;	
		endLine			;
	endfunction
	
	function hSTORE(input logic [4:0] l	,
					input logic [4:0] r	);
		
		opCode	= `hstore	;
		dest	= 5'b0		;
		left	= l			;
		value	= {r, 11'b0};	
		endLine				;
	endfunction
	
	// RUNNING
	initial begin 	addrCounter	= 0;
					`include "0_hProgram.sv" // first pass
					addrCounter	= 0;
					`include "0_hProgram.sv" // second pass
			end
			