/************************************************************
File: 2_hostProcessor.sv
Name: Host Processor
Description:
************************************************************/
//`include "0_DEFINES.vh"
module hostProcessor(	
		output	logic 					h2iPwrite		,	
		input	logic 					i2hPfull		,   
		input	logic [12:0]			cInstr			,   
		output	logic 					h2iDwrite   	,   
		input	logic 					i2hDfull		,   
		output	logic 					h2iDread   		,   
		input	logic 					i2hDempty   	,   
		output	logic 					selProgOut		,   
		output	logic [63:0]			prog2int		,   
		output	logic [$clog2(`m)-1:0]	hostProgAddr	,   
		input	logic [31:0]			instruction		,   
		output	logic [$clog2(`m)-1:0]	transAddr		,   
		input	logic [`n-1:0]			procDataIn		,   
		output	logic [`n-1:0]			procDataOut		,   
		output	logic 					procWrite		,   
		output	logic [$clog2(`m):0]	procAddr		,   
		input	logic 					a2hInt			,   
		output	logic 					h2aInta			,   
		input	logic 					reset, clock	);  	
	logic [1:0]		loadCom			;
	logic [31:0]	leftOut			;
	logic [31:0]	hostCycleCounter;
	
	assign procAddr 	= leftOut[$clog2(`m):0]		;
	assign transAddr 	= leftOut[$clog2(`m)-1:0]	;
	hostDCD hDCD
		(	.instr		(instruction	),
			.writeEnable(writeEnable	),
			.loadCom	(loadCom		),
			.h2iPwrite	(h2iPwrite		),
			.h2iDwrite  (h2iDwrite		),
			.h2iDread 	(h2iDread 		),
			.procWrite	(procWrite		),
			.selProgOut	(selProgOut		),
			.prog2int	(prog2int		));	
	hostPC hPC(	
		.host2accInta		(h2aInta					),
		.acc2hostInt		(a2hInt						),
		.cInstr				(cInstr						),
		.leftEqRigth		(leftOut ==	procDataOut		),
		.leftOut			(leftOut					),
		.hostProgAddr		(hostProgAddr				),
		.hOpCode			(instruction[31:26]			),
		.value				(instruction[$clog2(`m)-1:0]),
		.hostCycleCounter	(hostCycleCounter			),
		.reset				(reset						), 
		.clock				(clock						));	
	hostRALU hRALU
		(	.writeEnable(writeEnable		),
			.destAddr	(instruction[25:21]	),
			.leftAddr	(instruction[20:16]	),
			.rightAddr	(instruction[15:11]	),
			.value		(instruction[15:0]	),
			.procDataIn	(procDataIn			),
			.hFunction	(instruction[31:26]	),
			.i2hPfull	(i2hPfull			),
			.i2hDfull	(i2hDfull			),
			.i2hDempty	(i2hDempty			),
			.loadCom	(loadCom			),
			.leftOut	(leftOut			),
			.rightOut	(procDataOut		),
			.clock		(clock				));
endmodule