/************************************************************
File: 3_controller.sv
Name: Controller
Description:
************************************************************/
module controller(	input	logic [63:0]	i2aProg		,	
					output	logic 			a2iPread	,   
					input	logic 			i2aPempty	,   
					output	logic [2:0]		dataTransCom,   
					output	logic 			a2iDread  	,   
					input	logic 			i2aDempty   ,   
					output	logic 			a2iDwrite  	,   
					input	logic 			i2aDfull  	,   
					output	logic [`n+12:0]	contr2array	,   
					input	logic [`n-1:0]	red			,   
					output	logic 			a2hInt		,   
					input	logic 			h2aInta		, 
					input	logic			reset		,
					input	logic			clock		);
	logic [$clog2(`m)-1:0]	progAddr	;
	logic [63:0]			dualInstr	;
	logic [63:0]			delayedInstr;
	logic [31:0]			contrMemIn	;
	logic [31:0]			contrMemOut	;
	logic [1:0]				accState	;
	logic 					initFunc	;
	logic 					getParam	;
		
	controller2distribute contr2distr(	
		.contr2array	(contr2array	),
		.contrMemIn		(contrMemIn		),
		.delayedInstr	(delayedInstr	),
		.clock			(clock			));	
	controllerProgramMemory contrProgMem(	i2aProg		,
											a2iPread	,
											i2aPempty	,
											progAddr	,
											dualInstr	,
											delayedInstr,
											accState	,
											initFunc	,
											getParam	,
											reset, clock);	
	controllerDataMemory contrDataMem(	
		.contrDataAddr	 (dualInstr[$clog2(`m)-1:0]		),
		.contrDelDataAddr(delayedInstr[$clog2(`m)-1:0] 	),
		.contrMemOut	 (contrMemOut					),
		.contrMemIn		 (contrMemIn					),
		.contrMemCom	 (dualInstr[31:24]				),
		.contrDelMemCom	 (delayedInstr[31:19]			),
		.clock			 (clock							));	
	controllerProcessor contrProc(	
		.progAddr		(progAddr			),
		.instr			(dualInstr[31:0]	),
		.delayedInstr	(delayedInstr[31:0]	),
		.contrMemOut	(contrMemOut		),
		.contrMemIn		(contrMemIn			),
		.dataTransCom	(dataTransCom		),
		.a2iDread   	(a2iDread   		),
		.i2aDempty    	(i2aDempty    		),
		.a2iDwrite   	(a2iDwrite   		),
		.i2aDfull  		(i2aDfull  			),
		.red2contr		(red				),
		.a2hInt			(a2hInt				),
		.h2aInta		(h2aInta			),
		.accState		(accState			),
		.initFunc		(initFunc			),
		.getParam		(getParam			),
		.int2accProg	(i2aProg[31:0]		),
		.reset			(reset				), 
		.clock			(clock				));							
endmodule