/************************************************************
File:4_controllerDataMemory.sv
Name: Controller Data Memory
Description:
************************************************************/
module controllerDataMemory (	
		input	logic [$clog2(`m)-1:0] 	contrDataAddr	,
		input	logic [$clog2(`m)-1:0] 	contrDelDataAddr,
		output	logic [`n-1:0]			contrMemOut		,
		input	logic [`n-1:0]			contrMemIn		,
		input	logic [7:0]				contrMemCom		,
		input	logic [12:0]			contrDelMemCom	,
		input	logic 					clock			);
// memCom: 00:nop; 01:absolute; 10:rel; 11:rel+update
	logic [31:0]			contrDM[0:`m-1]	;
	logic [$clog2(`m)-1:0] 	contrAddrReg	;
	logic [1:0]				wCom            ;
	logic [1:0]				rCom            ;
	logic [$clog2(`m)-1:0]	wAddr			;
	logic [$clog2(`m)-1:0]	rAddr			;
	logic 					addrLoad		;
	
// Transcode: 
//memCom: 00:nop; 01:abs; 10:rel; 11:rel+update
	always_comb case(contrDelMemCom[12:5])
					{`cstore,`dir}: wCom = 2'b01;
					{`cstore,`cdr}: wCom = 2'b01;
					{`cstore,`rel}: wCom = 2'b10;
					{`cstore,`crl}: wCom = 2'b10;
					{`cstore,`rei}: wCom = 2'b11;
					{`cstore,`cri}: wCom = 2'b11;
					default: 		wCom = 2'b00;
				endcase			
	always_comb if (contrMemCom[7:3] == `cstore)
					rCom = 2'b00;
				  else	case(contrMemCom[2:0])
							`dir: 	rCom = 2'b01;
							`cdr: 	rCom = 2'b01;
							`rel: 	rCom = 2'b10;
							`crl: 	rCom = 2'b10;
							`rei: 	rCom = 2'b11;
							`cri: 	rCom = 2'b11;
							default:rCom = 2'b00;
						endcase 				
	assign addrLoad = 
			{`contr, `imm, `crela} == contrDelMemCom;	
// Address compute
	always_comb	
	 case(wCom[1:0])
		2'b01: wAddr = contrDelDataAddr					;
		2'b10: wAddr = contrAddrReg + contrDelDataAddr	;
		2'b11: wAddr = contrAddrReg + contrDelDataAddr	;
	  default: wAddr = contrDelDataAddr					;
	 endcase				
	always_comb	
	 case(rCom[1:0])
		2'b01: rAddr = contrDataAddr				;
		2'b10: rAddr = contrAddrReg + contrDataAddr	;
		2'b11: rAddr = contrAddrReg + contrDataAddr	;
	  default: rAddr = contrDataAddr				;
	 endcase
// Operation
	always_ff @(posedge clock)	begin	
	 if (|rCom) 	contrMemOut 	<= contrDM[rAddr]	;
	 if (|wCom) 	contrDM[wAddr] 	<= contrMemIn		;
	 if (&wCom) 	contrAddrReg 	
					<= contrAddrReg + contrDelDataAddr	;
	 if (&rCom) 	contrAddrReg 	
					<= contrAddrReg + contrDataAddr		;
	 if (addrLoad) 	contrAddrReg 	
					<= contrMemIn[$clog2(`m)-1:0]		;
	end	
endmodule