/************************************************************
File: 4_controllerProcessor.sv
Name: Controller Processor
Description:
************************************************************/
module controllerProcessor (	
		output	logic [$clog2(`m)-1:0]	progAddr	,				
		input	logic [31:0]			instr		,       
		input	logic [31:0]			delayedInstr,       
		input	logic [31:0]			contrMemOut	,       
		output	logic [31:0]			contrMemIn	,       
		output	logic [2:0]				dataTransCom,       
		output	logic 					a2iDread   	,       
		input	logic 					i2aDempty  	,       
		output	logic 					a2iDwrite   ,       
		input	logic 					i2aDfull  	,       
		input	logic [`n-1:0]			red2contr	,       
		output	logic 					a2hInt		,       
		input	logic 					h2aInta		,       
		input	logic [1:0]				accState	,       
		input	logic 					initFunc	,       
		input	logic 					getParam	,       
		input	logic [31:0]			int2accProg	,       
		input	logic 					reset, clock);                                                               
	logic endTransfer	;
	logic zero			;

	controllerCom contCom(	
		.a2hInt			(a2hInt			),
		.h2aInta		(h2aInta		),
		.instr			(instr			),
		.dataTransCom	(dataTransCom	),
		.endTransfer	(endTransfer	),
		.a2iDread   	(a2iDread   	),
		.i2aDempty  	(i2aDempty  	),
		.a2iDwrite   	(a2iDwrite   	),
		.i2aDfull  		(i2aDfull  		),
		.reset			(reset			), 
		.clock			(clock			));	
	controllerPC contrPC(	
		.progAddr	(progAddr					),
		.instr		(instr						),
		.zero		(zero						),
		.endTransfer(endTransfer				),
		.accState	(accState					),
		.initFunc	(initFunc					),
		.initAddr	(int2accProg[$clog2(`m)-1:0]),
		.reset		(reset						), 
		.clock		(clock						));	
	controllerAALU contAALU(
		.instruction(delayedInstr	),
		.contrMemOut(contrMemOut	),
		.red2contr	(red2contr		),
		.int2accProg(int2accProg	),
		.cAcc		(contrMemIn		),
		.zero		(zero			),
		.clock		(clock			));	
endmodule