/************************************************************
File: 4_controllerProgramMemory.sv
Name: Controller Program Memory
Description:
************************************************************/
module controllerProgramMemory(	
		input	logic [63:0]			i2aProg		,	
		output	logic 					a2iPread	,   
		input	logic 					i2aPempty	,   
		input	logic [$clog2(`m)-1:0]	progAddr	,   
		output	logic [63:0]			dualInstr	,   
		output	logic [63:0]			delayedInstr,   
		output	logic [1:0]				accState	,   
		output	logic 					initFunc	,   
		output	logic 					getParam	,   
		input	logic 					reset, clock);  
	logic [63:0]			contrPM[0:`m-1]	;
	logic [$clog2(`m)-1:0]	loadReg			;
	
	always_ff @(posedge clock)
		if (reset) 	accState <= `idle	; 
		 else begin 
				if ((accState == `idle) && !i2aPempty && 
					(i2aProg[31:24] == {`contr, `imm}) &&
					(i2aProg[23:19] == `pload)) 	
					accState <= `loading;
				if ((accState == `idle) && !i2aPempty && 
					(i2aProg[31:24] == {`contr, `imm}) &&
					(i2aProg[23:19] == `prun)) 	
					accState <= `running;
				if ((accState == `loading) && !i2aPempty && 
					(i2aProg[31:24] == {`contr, `imm}) &&
					(i2aProg[23:19] == `prun)) 	
					accState <= `running;
				if ((accState == `running) && 
					(dualInstr[31:24] == {`contr, `imm}) &&
					(dualInstr[23:19] == `halt)) 					
					accState <= `idle	;
			end	
	assign initFunc = 
				(accState == `idle) && !i2aPempty && 
				(i2aProg[31:24] == {`contr, `imm}) &&
				(i2aProg[23:19] == `prun)				;
	assign getParam = 
				(accState == `running) && !i2aPempty && 
				(delayedInstr[31:24] == {`contr, `imm}) &&
				(delayedInstr[23:19] == `param)				;
	always_ff @(posedge clock)	begin
		if (accState == `idle) 						
				loadReg <= i2aProg[$clog2(`m)-1:0]	;
		if ((accState == `loading) && !i2aPempty) 	
				loadReg <= loadReg + 1					;
		if (accState == `running)					
				loadReg <= loadReg						;
		end		
	always_ff @(posedge clock)	
		if ((accState == `loading) && !i2aPempty) 
				contrPM[loadReg] <= i2aProg	;
	
	always_ff @(posedge clock)	begin 	
		dualInstr 	 <= (accState == `running) ? 
						contrPM[progAddr] : 0	;
		delayedInstr <= dualInstr				;
	end
	assign a2iPread  = ((accState == `loading) && !i2aPempty) 
						|| initFunc || getParam	;											
endmodule