/************************************************************
File: 4_hostALU.sv
Name:
Description:
************************************************************/
module hostALU (	output	logic [31:0]	result		,
					input	logic [31:0]	leftOut		,
					input	logic [31:0]	rightOut	,
					input	logic [15:0]	value		,
					input	logic [5:0]		hFunction	,
					input	logic 			i2hPfull	,
					input	logic 			i2hDfull	,
					input	logic 			i2hDempty	,
					input	logic 			clock		);		
	logic 			crFF	;
	logic 			cr		;
	logic [31:0]	rightVal;
	
	assign rightVal = {{16{value[15]}}, value}	;				
	always_comb 
	 case(hFunction[5:0])
		`hadd    : {cr, result} = leftOut + rightOut		  	;
		`haddcr  : {cr, result} = leftOut + rightOut + crFF 	;
		`hsub    : {cr, result} = leftOut - rightOut		  	;
		`hsubcr  : {cr, result} = leftOut - rightOut - crFF 	;
		`hmult   : {cr, result} = {crFF, leftOut * rightOut}	;
		`hbwand  : {cr, result} = {crFF, leftOut & rightOut}	;
		`hbwor   : {cr, result} = {crFF, leftOut | rightOut}	;
		`hbwxor  : {cr, result} = {crFF, leftOut ^ rightOut}	;
		`haddv   : {cr, result} = leftOut + rightVal		  	;
		`haddcrv : {cr, result} = leftOut + rightVal + crFF 	;
		`hsubv   : {cr, result} = leftOut - rightVal		  	;
		`hsubcrv : {cr, result} = leftOut - rightVal - crFF 	;
		`hmultv  : {cr, result} = {crFF, leftOut * rightVal}	;
		`hbwandv : {cr, result} = {crFF, leftOut & rightVal}	;
		`hbworv  : {cr, result} = {crFF, leftOut | rightVal}	;
		`hbwxorv : {cr, result} = {crFF, leftOut ^ rightVal}	;
		`hpsend  : {cr, result} = {crFF, leftOut + !i2hPfull}	;
		`hdsend  : {cr, result} = {crFF, leftOut + !i2hDfull}	;
		`hdget   : {cr, result} = {crFF, leftOut + !i2hDempty}	;
		default  : {cr, result} = {crFF, 32'bx}					;
	 endcase				
	always_ff @(posedge clock)	crFF <= cr	;
endmodule