/************************************************************
File: 4_map.sv
Name: Map section
Description:
************************************************************/
//`include "0_DEFINES.vh"
module map(	input	logic [63:0]	int2accData			,
			output	logic [63:0] 	a2i					,
			input	logic [2:0]		dataTransCom		,
			input	logic [`n+12:0]	contr2array			,
			output	logic [`n+1:0] 	map2reduce[0:`p-1]	,
			input	logic [`n-1:0]	red					,
			output	logic [0:`p-1]	boolean				,
			input	logic [0:`p-1]	first				,
			input	logic [0:`p-1]	next				,
			input	logic 			clock				);
// dataTransCom : 000 : nop
// dataTransCom : 100 : even insert
// dataTransCom : 101 : odd insert
// dataTransCom : 110 : even extract
// dataTransCom : 111 : odd extract
	logic [`n:0]		leftEndIn			;
	logic [`n-1:0]		rightEndIn			;
	logic [0:`p/2-1]	boolean0			;
	logic [0:`p/2-1]	boolean1			;
	logic [0:`p/2-1]	first0         		;
	logic [0:`p/2-1]	first1         		;
	logic [0:`p/2-1]	next0         		;
	logic [0:`p/2-1]	next1         		;
	logic [`n:0]		rightOut0[0:`p/4-1]	;
	logic [`n-1:0]		leftOut0[0:`p/4-1]	;
	logic [`n:0]		rightOut1[0:`p/4-1]	;
	logic [`n-1:0]		leftOut1[0:`p/4-1]	; 
	logic 				insSerial			;
	logic [1:0]			rotateSelLeft		;		
	logic [1:0]			rotateSelRight		;
	logic [63:0] 		acc2intData0		;
	logic [63:0] 		acc2intData1		;
	integer	i, j, k	;

	always_comb for(i=0; i<`p; i= i+1) 	
		case(i[1:0])
			2'b00: boolean[i] = boolean0[2*(i/4)]  	;	
			2'b01: boolean[i] = boolean0[2*(i/4)+1]	;		
			2'b10: boolean[i] = boolean1[2*(i/4)] 	;
			2'b11: boolean[i] = boolean1[2*(i/4)+1] ;
		endcase					
	always_comb for(j=0; j<`p/4; j= j+1) begin
		{first0[2*j], first0[2*j+1]} = 
		{first[4*j],  first[4*j+1]}		;
		{first1[2*j], first1[2*j+1]} = 
		{first[4*j+2],first[4*j+3]}		;
	end
	always_comb for(k=0; k<`p/4; k= k+1) begin
		{next0[2*k], next0[2*k+1]} = 
		{next[4*k],  next[4*k+1]}	;
		{next1[2*k], next1[2*k+1]} = 
		{next[4*k+2],next[4*k+3]}	;
	end	
	always_comb 
		case(rotateSelLeft)
			2'b00: leftEndIn = {`n+1{1'b0}}						; 
			2'b01: leftEndIn = {1'b0, rightOut1[`p/4-1][`n-1:0]};
			2'b10: leftEndIn = {1'b0, red}						;
			2'b11: leftEndIn = {`n+1{1'b0}}						;
		endcase				
	always_comb 
		case(rotateSelRight)
			2'b00: rightEndIn =	{`n{1'b0}}	; 
			2'b01: rightEndIn =	leftOut0[0]	;
			2'b10: rightEndIn =	red			;
			2'b11: rightEndIn =	{`n{1'b0}}	;
		endcase		
	assign a2i = dataTransCom[0] ? acc2intData0 : acc2intData1	;				
	column col0(
	  .int2accData		(int2accData						),
	  .acc2intData		(acc2intData1						),
	  .dataTransCom		(dataTransCom						),
	  .map2reduce		(map2reduce[0:`p/2-1]				),
	  .boolean			(boolean0							),
	  .first			(first0								),
	  .next				(next0								),
	  .rightOut			(rightOut0[0:`p/4-1]				),
	  .leftIn			({leftEndIn, rightOut1[0:`p/4-2]}	),
	  .leftOut			(leftOut0[0:`p/4-1]					),
	  .rightIn			(leftOut1[0:`p/4-1]					),
	  .contr2array		(contr2array						),
	  .rotateSelLeft	(rotateSelLeft						),		
	  .rotateSelRight	(									),	
	  .index			(1'b0								), 
	  .clock			(clock								));				
	column col1(
	 .int2accData  		(int2accData						),
	 .acc2intData  		(acc2intData0						),
	 .dataTransCom 		({dataTransCom[2:1],!dataTransCom[0]}),
	 .map2reduce   		(map2reduce[`p/2:`p-1]				),
	 .boolean	   		(boolean1							),
	 .first		   		(first1								),
	 .next		   		(next1								),
	 .rightOut	   		(rightOut1[0:`p/4-1]				),
	 .leftIn	   		(rightOut0[0:`p/4-1]				),
	 .leftOut	   		(leftOut1[0:`p/4-1]					),
	 .rightIn	   		({leftOut0[1:`p/4-1], rightEndIn}	),
	 .contr2array  		(contr2array						),
	 .rotateSelLeft		(									),		
	 .rotateSelRight	(rotateSelRight						),
	 .index		   		(1'b1								),
	 .clock		   		(clock								));
endmodule