/************************************************************
File:
Name: Control communication control
Description:
************************************************************/
//`include "0_DEFINES.vh"
module controllerCom(	
		output	logic 			a2hInt		,	
		input	logic 			h2aInta		,   
		input	logic [31:0]	instr		,   
		output	logic [2:0]		dataTransCom,   
		output	logic 			endTransfer	,   
		output	logic 			a2iDread   	,   
		input	logic 			i2aDempty  	,   
		output	logic 			a2iDwrite   ,   
		input	logic 			i2aDfull  	,   
		input	logic 			reset, clock);  
                                                
//*
// INTERRUPT TO HOST
	always_ff @(posedge clock) 
	 if (reset) 						  				a2hInt <= 0;
	  else if (instr[31:19] == {`contr, `imm, `setint})	a2hInt <= 1;
		else if (h2aInta) 			  					a2hInt <= 0;
	
// DATA TRANSFER CONTROL	
// dataTransCom : 000 : nop
// dataTransCom : 100 : even insert
// dataTransCom : 101 : odd insert
// dataTransCom : 110 : even extract
// dataTransCom : 111 : odd extract 
		
	reg	[23:0]	transCounter;
	
	always_ff @(posedge clock) begin
		if (reset)					transCounter <= 0				;
		if (a2iDread || a2iDwrite) 	transCounter <= transCounter + 1;
		if (endTransfer)			transCounter <= 0				;
		end
		
	assign a2iDread 		= !endTransfer && (instr[31:19] == {`contr, `imm, `datains}) && !i2aDempty	;
	assign a2iDwrite 		= !endTransfer && (instr[31:19] == {`contr, `imm, `dataext}) && !i2aDfull	;
	assign dataTransCom[2] 	= a2iDread || a2iDwrite														;
	assign dataTransCom[1] 	= (instr[31:19] == {`contr, `imm, `dataext})								;
	assign dataTransCom[0] 	= transCounter[0] ^ (instr[31:19] == {`contr, `imm, `datains})				;
	assign endTransfer 		= transCounter == instr[18:0]												;
//*/							   
endmodule