/************************************************************
File:
Name:
Description:
************************************************************/
//`include "0_DEFINES.vh"
module dualCell(
		input	logic [63:0]			ioIn			,
		output	logic [63:0] 			ioOut			,
		input	logic 					prevState		,
		input	logic 					nextState		,
		output	logic 					state			,
		output	logic [`n+1:0] 			map2reduce[0:1]	,
		output	logic [0:1]				boolean			,
		input	logic [0:1]				first			,
		input	logic [0:1]				next			,
		output	logic [`n:0]			rightOut		,
		input	logic [`n:0]			leftIn			,
		output	logic [`n-1:0]			leftOut			,
		input	logic [`n-1:0]			rightIn			,
		input	logic [`n+12:0]			fromDistr		,
		input	logic [$clog2(`p)-2:0]	index			,
		input	logic 					clock			);
//*				
	logic [`n+12:0]	instr		;
	logic [`n+12:0]	preInstr	;
	logic [`n:0]	leftOut1	;
	logic 			advance		; // local io takes the previous
	logic 			set			;
	logic 			rst			;
	logic [`n:0]	serialReg1	;	
	logic [`n:0]	serialReg0	;
	logic 			noOpInstr	;
	
	always_ff @(posedge clock)	begin instr		<= preInstr	;		
									  preInstr	<= fromDistr;
								end
							
	assign rightOut = serialReg1;
	assign leftOut	= serialReg0;	
	
	assign noOpInstr = instr[`n+7:`n] == {`contr, `imm}	;	
				
	arrayCell arrayCell0(	
		.instr		(instr						),
		.noOpInstr	(noOpInstr					),
		.readAddr	(preInstr[$clog2(`m)-1:0]	),
		.readCom	(preInstr[`n+7:`n]			),
		.ioIn		(ioIn[63:32]				),
		.ioOut		(ioOut[63:32]				),
		.advance	(advance					),
		.set		(set						),
		.rst		(rst						),
		.map2reduce	(map2reduce	[0]				),
		.boolean	(boolean[0]					),
		.first		(first[0]					),
		.next		(next[0]					),
		.serialReg	(serialReg0					),
		.leftIn		(leftIn						),
		.rightIn	(serialReg1[`n-1:0]			),
		.index		({index, 1'b0}				),
		.clock		(clock						));
	
	arrayCell arrayCell1(	
		.instr		(instr						),
		.noOpInstr	(noOpInstr					),
		.readAddr	(preInstr[$clog2(`m)-1:0]	),
		.readCom	(preInstr[`n+7:`n]			),
		.ioIn		(ioIn[31:0]	 				),
		.ioOut		(ioOut[31:0] 				),
		.advance	(advance					),
		.set		(							),
		.rst		(							),
		.map2reduce	(map2reduce	[1]				),
		.boolean	(boolean[1]					),
		.first		(first[1]					),
		.next		(next[1]					),
		.serialReg	(serialReg1					),
		.leftIn		(serialReg0					),
		.rightIn	(rightIn					),
		.index		({index, 1'b1}				),
		.clock		(clock						));
							
	propAutom propAutom(   
		.com   		(advance	), // load  the local register
		.state 		(state		), // the local state of the cell
		.set   		(set		), // set cell state on "full"  
		.rst   		(rst		), // set cell state in "empty" 
		.prevState  (prevState	), // state of the previous cell
		.nextState  (nextState	), // state of the next cell
		.clock 		(clock		));
//*/				
endmodule