// in CONTROLLER
	// immediate addition: acc <= acc + cScalar
	function cVADD(input logic [23:0] value); 
		cOpCode 	= `cadd	;
		cOperand 	= `imm	;
		cScalar		= value	;
	endfunction
	
	// direct addressing addition: 
	// acc <= acc + mem[cScalar[s-1:0]]
	function cADD(input logic [9:0] value); 
		cOpCode 	= `cadd	;
		cOperand 	= `dir	;
		cScalar		= value	;
	endfunction

	// relative addressing addition: 
	// acc <= acc + mem[addr + cScalar[s-1:0]]
	function cRADD(input logic [9:0] value); 
		cOpCode 	= `cadd	;
		cOperand 	= `rel	;
		cScalar		= value	;
	endfunction
	
	// relative addressing addition with address update: 
	// acc <= acc + mem[addr + cScalar[s-1:0]]
	// addr = addr + cScalar[s-1:0]
	function cRIADD(input logic [9:0] value); 
		cOpCode 	= `cadd	;
		cOperand 	= `rei	;
		cScalar		= value	;
	endfunction
	
	// cooperand addressing addition:
	// acc <= acc + coOperand = acc + redOut
	function cCADD; 
		cOpCode 	= `cadd	;
		cOperand 	= `cim	;
		cScalar		= 24'b0	;
	endfunction

// in ARRAY
	// value add: acc[i] <= acc[i] + aScalar
	function VADD(input logic [23:0] value); 
		aOpCode 	= `add	;
		aOperand 	= `imm	;
		aScalar		= value	;
		endLineA			;
	endfunction
	
	// direct add: acc[i] <= acc[i] + vectMem[i][aScalar]
	function ADD(input logic [23:0] value);
		aOpCode 	= `add	;
		aOperand 	= `dir	;
		aScalar		= value	;
		endLineA			;
	endfunction
	
	// relative add: 
	// acc[i] <= acc[i] + vectMem[i][addrVect[i] + aScalar[v-1:0]]
	function RADD(input logic [23:0] value);
		aOpCode 	= `add	;
		aOperand 	= `rel	;
		aScalar		= value	;
		endLineA			;
	endfunction
	
	// relative add and increment: 
	// acc[i] <= acc[i] + vectMem[i][addrVect[i] + aScalar[v-1:0]]
	// addrVect[i] <= addrVect[i] + aScalar[v-1:0]
	function RIADD(input logic [23:0] value);
		aOpCode 	= `add	;
		aOperand 	= `rei	;
		aScalar		= value	;
		endLineA			;
	endfunction
	
	// co-operand add: acc[i] <= acc[i] + acc
	function CADD; 
		aOpCode 	= `add	;
		aOperand 	= `cim	;
		aScalar		= 24'b0	;
		endLineA			;
	endfunction
	
	// co-operand direct add:
	// acc[i] <= acc[i] + vectMem[i][acc[v-1:0]]
	function CAADD; 
		aOpCode 	= `add	;
		aOperand 	= `cdr	;
		aScalar		= 24'b0	;
		endLineA			;
	endfunction
	
	// co-operand relative add: 
	// acc[i] <= acc[i] + vectMem[i][addrVect[i] + acc[v-1:0]]
	function CRADD; 	
		aOpCode 	= `add	;
		aOperand 	= `crl	;
		aScalar		= 24'b0	;
		endLineA			;	
	endfunction	
	
	// co-operand relative add & addr update: 
	// acc[i] <= acc[i] + vectMem[i][addrVect[i] + acc[v-1:0]]
	// addrVect[i] <= addrVect[i] + acc[v-1:0]
	function CRIADD; 
		aOpCode 	= `add	;
		aOperand 	= `cri	;
		aScalar		= 24'b0	;
		endLineA			;	
	endfunction
	
	function SRADD; 
		aOpCode 	= `contr			; 
		aOperand 	= `imm				; 
		aScalar		= {`sradd, 19'b0}	; 
		endLineA						;	
	endfunction