// in CONTROLLER
	// immediate addition with carry:acc <= acc + cScalar
	function cVADDC(input logic [23:0] value);	
		cOpCode 	= `caddcr	;
		cOperand 	= `imm		;
		cScalar		= value		;
	endfunction
	
	// direct addressing addition with carry: 
	// acc <= acc + mem[cScalar[s-1:0]]
	function cADDC(input logic [9:0] value);
		cOpCode 	= `caddcr	;
		cOperand 	= `dir		;
		cScalar		= value		;
	endfunction

	// relative addressing addition with carry: 
	// acc <= acc + mem[addr + cScalar[s-1:0]]
	function cRADDC(input logic [9:0] value);	
		cOpCode 	= `caddcr	;
		cOperand 	= `rel		;
		cScalar		= value		;
	endfunction
	
	// relative addressing addition with carry with address update: 
	// acc <= acc + mem[addr + cScalar[s-1:0]]
	// addr = addr + cScalar[s-1:0]
	function cRIADDC(input logic [9:0] value);
		cOpCode 	= `caddcr	;
		cOperand 	= `rei		;
		cScalar		= value		;
	endfunction
	
	// cooperand addressing addition with carry:
	// acc <= acc + coOperand
	function cCADDC; 
		cOpCode 	= `caddcr	;
		cOperand 	= `cim		;
		cScalar		= 24'b0		;
	endfunction
	
	
// in ARRAY
	// value add with carry: 
	// acc[i] <= acc[i] + aScalar + carry
	function VADDC(input logic [23:0] value);	
		aOpCode 	= `addcr;
		aOperand 	= `imm	;
		aScalar		= value	;
		endLineA			;
	endfunction
	
	// absolute add with carry
	// acc[i] <= acc[i] + vectMem[i][aScalar] + carry
	function ADDC(input logic [23:0] value);	
		aOpCode 	= `addcr;
		aOperand 	= `dir	;
		aScalar		= value	;
		endLineA			;
	endfunction
	
	// relative add with carry: 
	// acc[i] <= acc[i] + vectMem[i][addrVect[i] + aScalar[v-1:0]] + carry
	function RADDC(input logic [23:0] value);	
		aOpCode 	= `addcr;
		aOperand 	= `rel	;
		aScalar		= value	;
		endLineA			;
	endfunction
	
	// relative add with carry and increment: 
	// acc[i] <= acc[i] + vectMem[i][addrVect[i] + aScalar[v-1:0]] + carry
	// addrVect[i] <= addrVect[i] + aScalar[v-1:0]
	function RIADDC(input logic [23:0] value);
		aOpCode 	= `addcr;
		aOperand 	= `rei	;
		aScalar		= value	;
		endLineA			;
	endfunction
	
	// co-operand add with carry: 
	// acc[i] <= acc[i] + acc + carry
	function CADDC; 
		aOpCode 	= `addcr;
		aOperand 	= `cim	;
		aScalar		= 24'b0	;
		endLineA			;
	endfunction
	
	// co-operand absolute add with carry
	// acc[i] <= acc[i] + vectMem[i][acc[v-1:0]] + carry
	function CAADDC;	
		aOpCode 	= `addcr;
		aOperand 	= `cdr	;
		aScalar		= 24'b0	;
		endLineA			;
	endfunction
	
	// co-operand relative add with carry: 
	// acc[i] <= acc[i] + vectMem[i][addrVect[i] + acc[v-1:0]] + carry
	function CRADDC; 		
		aOpCode 	= `addcr;
		aOperand 	= `crl	;
		aScalar		= 24'b0	;
		endLineA			;
	endfunction

	// co-operand relative add with carry & update addr: 
	// acc[i] <= acc[i] + vectMem[i][addrVect[i] + acc[v-1:0]] + carry
	// addrVect[i] <= addrVect[i] + acc[v-1:0]
	function CRIADDC; 		
		aOpCode 	= `addcr;
		aOperand 	= `cri	;
		aScalar		= 24'b0	;
		endLineA			;
	endfunction