// in CONTROLLER
	// immediate AND-ing: acc <= acc & cScalar
	function cVAND(input logic [23:0] value);	
		cOpCode 	= `cbwand	;
		cOperand 	= `imm		;
		cScalar		= value		;	
	endfunction
	
	// immediate addressing AND-ing: 
	// acc <= acc & mem[cScalar[s-1:0]] 
	function cAND(input logic [9:0] value);	
		cOpCode 	= `cbwand	;
		cOperand 	= `dir		;
		cScalar		= value		;
	endfunction

	// relative addressing AND-ing: 
	// acc <= acc & mem[addr + cScalar[s-1:0]]
	function cRAND(input logic [9:0] value);	
		cOpCode 	= `cbwand	;
		cOperand 	= `rel		;
		cScalar		= value		;
	endfunction
	
	// relative addressing AND-ing additiwith address update: 
	// acc <= acc & mem[addr + cScalar[s-1:0]]
	// addr = addr + cScalar[s-1:0]
	function cRIAND(input logic [9:0] value);	
		cOpCode 	= `cbwand	;
		cOperand 	= `rei		;
		cScalar		= value		;
	endfunction
	
	// cooperand addressing AND-ing: acc <= acc & coOperand
	function cCAND; 	
		cOpCode 	= `cbwand	;
		cOperand 	= `cim		;
		cScalar		= 24'b0		;
	endfunction
	
// in ARRAY
	// value AND-ing: acc[i] <= acc[i] & aScalar
	function VAND(input logic [23:0] value);	
		aOpCode 	= `bwand;
		aOperand 	= `imm	;
		aScalar		= value	;
		endLineA			;
	endfunction
	
	// absolute AND-ing
	// acc[i] <= acc[i] & vectMem[i][aScalar]
	function AND(input logic [23:0] value);	
		aOpCode 	= `bwand;
		aOperand 	= `dir	;
		aScalar		= value	;
		endLineA			;
	endfunction
	
	// relative AND-ing: 
	// acc[i] <= acc[i] & vectMem[i][addrVect[i] + aScalar[v-1:0]]
	function RAND(input logic [23:0] value);	
		aOpCode 	= `bwand;
		aOperand 	= `rel	;
		aScalar		= value	;
		endLineA			;
	endfunction
	
	// relative AND-ing and increment: 
	// acc[i] <= acc[i] & vectMem[i][addrVect[i] + aScalar[v-1:0]]
	// addrVect[i] <= addrVect[i] + aScalar[v-1:0]
	function RIAND(input logic [23:0] value);	
		aOpCode 	= `bwand;
		aOperand 	= `rei	;
		aScalar		= value	;
		endLineA			;
	endfunction
	
	// co-operand AND-ing: 
	// acc[i] <= acc[i] & acc
	function CAND;
		aOpCode 	= `bwand;
		aOperand 	= `cim	;
		aScalar		= 24'b0	;
		endLineA			;
	endfunction
	
	// co-operand absolute AND-ing
	// acc[i] <= acc[i] & vectMem[i][acc[v-1:0]]
	function CAAND; 	
		aOpCode 	= `bwand;
		aOperand 	= `cdr	;
		aScalar		= 24'b0 ;
		endLineA			;
	endfunction
	
	// co-operand relative AND-ing 
	// acc[i] <= acc[i] & vectMem[i][addrVect[i] + acc[v-1:0]]
	function CRAND; 	
		aOpCode 	= `bwand;
		aOperand 	= `crl	;
		aScalar		= 24'b0 ;
		endLineA			;
	endfunction	
	
	// co-operand relative AND-ing & update addr
	// acc[i] <= acc[i] & vectMem[i][addrVect[i] + acc[v-1:0]]
	// addrVect[i] <= addrVect[i] + acc[v-1:0]
	function CRIAND; 	
		aOpCode 	= `bwand;
		aOperand 	= `cri	;
		aScalar		= 24'b0 ;
		endLineA			;
	endfunction