/************************************************************
File name: cgHOST_LIBRARY.sv

					LOW LEVEL LIBRARY FUNCTIONS
					
************************************************************/
	// scalar send as parameter
	function hSSEND(input	logic [25:0]	scalar	);
		opCode	= `hssend			;
		{dest, left, value}	= scalar;	
		endLine						;
	endfunction
	
	// start controller's cycle counter
	function hSTART; 
		opCode	= `hfsend	;
		dest	= 5'b0		;
		left	= 5'b0		;
		value	= 16'b0100	;	
		endLine				;
	endfunction
	
	// stop controller's cycle counter
	function hSTOP; 
		opCode	= `hfsend	;
		dest	= 5'b0		;
		left	= 5'b0		;
		value	= 16'b0101	;	
		endLine				;
	endfunction
	
	// interrupt request
	function hINTRQ; 
		opCode	= `hfsend	;
		dest	= 5'b0		;
		left	= 5'b0		;
		value	= 16'b0110	;	
		endLine				;
	endfunction
	
	// square matrix X starting with vect[0]
	function hSQGENX(input	logic [25:0]	d	); 
		opCode	= `hfsend	;
		dest	= 5'b0		;
		left	= 5'b0		;
		value	= 16'b0111	;	
		endLine				;
		opCode	= `hssend		;
		{dest, left, value}	= d	;
		endLine					;	
	endfunction
	
	// square matrix N starting with vect[0]
	function hSQGENN(input	logic [25:0]	d	);
		opCode	= `hfsend	;
		dest	= 5'b0		;
		left	= 5'b0		;
		value	= 16'b1000	;	
		endLine				;
		opCode	= `hssend		;
		{dest, left, value}	= d	;
		endLine					;
	endfunction
	
	// matrix send
	function hMSEND(input	logic [25:0]	address	,
					input	logic [25:0]	size	);
		opCode	= `hfsend	;
		dest	= 5'b0		;
		left	= 5'b0		;
		value	= 16'b1001	;	
		endLine				;
		opCode	= `hssend				;
		{dest, left, value}	= address	;	
		endLine							;								
		opCode	= `hssend				;
		{dest, left, value}	= size		;	
		endLine							;
	endfunction
	
	// matrix get
	function hMGET(	input	logic [25:0]	address	,
					input	logic [25:0]	size	);
		opCode	= `hfsend	;
		dest	= 5'b0		;
		left	= 5'b0		;
		value	= 16'b1010	;	
		endLine				;
		opCode	= `hssend				;
		{dest, left, value}	= address	;	
		endLine							;								
		opCode	= `hssend				;
		{dest, left, value}	= size		;	
		endLine							;
	endfunction
	
	// square main diagonal of v matrix starting at address
	function hMAIN(	input 	logic [25:0]	address	,
					input 	logic [25:0]	scalar	);
		opCode	= `hfsend	;
		dest	= 5'b0		;
		left	= 5'b0		;
		value	= 16'b1011	;	
		endLine				;
		opCode	= `hssend				;
		{dest, left, value}	= address	;	
		endLine							;
		opCode	= `hssend				;
		{dest, left, value}	= scalar	;	
		endLine							;
	endfunction
	
	// square matrices add
	function hSQMADD(	input	logic [25:0]	d	,	
						input	logic [25:0]	l	,
						input	logic [25:0]	r	);
		opCode	= `hfsend	;
		dest	= 5'b0		;
		left	= 5'b0		;
		value	= 16'b1100	;	
		endLine				;
		opCode	= `hssend		;
		{dest, left, value}	= d	;	
		endLine					;
		opCode	= `hssend		;
		{dest, left, value}	= l	;	
		endLine					;
		opCode	= `hssend		;
		{dest, left, value}	= r	;	
		endLine					;
	endfunction
	
	// index vector generate at address
	function hVGENX(input	logic [25:0]	address	);
		begin 	opCode	= `hfsend	;
				dest	= 5'b0		;
				left	= 5'b0		;
				value	= 16'b1101	;	
				endLine				;
				opCode	= `hssend				;
				{dest, left, value}	= address	;	
				endLine							;
		end
	endfunction
	
	// integer vector generate at address
	function hVGENN(input	logic [25:0]	address	,
					input	logic [25:0]	scalar	);
		opCode	= `hfsend	;
		dest	= 5'b0		;
		left	= 5'b0		;
		value	= 16'b1110	;	
		endLine				;
		opCode	= `hssend				;
		{dest, left, value}	= address	;	
		endLine							;
		opCode	= `hssend				;
		{dest, left, value}	= scalar	;	
		endLine							;
	endfunction
	
	// square matrice vector multiply
	function hSQMVMULT(	input	logic [25:0]	d	,	
						input	logic [25:0]	l	,
						input	logic [25:0]	r	);
		opCode	= `hfsend	;
		dest	= 5'b0		;
		left	= 5'b0		;
		value	= 16'b1111	;	
		endLine				;
		opCode	= `hssend		;
		{dest, left, value}	= d	;
		endLine					;
		opCode	= `hssend		;
		{dest, left, value}	= l	;
		endLine					;	
		opCode	= `hssend		;
		{dest, left, value}	= r	;
		endLine					;
	endfunction
	
	// square matrices multiply
	function hSQMMULT(	input	logic [25:0]	d	,	
						input	logic [25:0]	l	,
						input	logic [25:0]	r	);
		opCode	= `hfsend	;
		dest	= 5'b0		;
		left	= 5'b0		;
		value	= 16'b10000	;	
		endLine				;
		opCode	= `hssend		;
		{dest, left, value}	= d	;
		endLine					;
		opCode	= `hssend		;
		{dest, left, value}	= l	;
		endLine					;	
		opCode	= `hssend		;
		{dest, left, value}	= r	;
		endLine					;
	endfunction

	// square matrices multiply-accumulate
	function hSQMMAC(	input	logic [25:0]	d	,	
						input	logic [25:0]	l	,
						input	logic [25:0]	r	);
		opCode	= `hfsend	;
		dest	= 5'b0		;
		left	= 5'b0		;
		value	= 16'b10001	;	
		endLine				;
		opCode	= `hssend		;
		{dest, left, value}	= d	;
		endLine					;
		opCode	= `hssend		;
		{dest, left, value}	= l	;
		endLine					;	
		opCode	= `hssend		;
		{dest, left, value}	= r	;
		endLine					;
	endfunction
	
	// square matrix transpose
	function hTRANS(	input	logic [25:0]	d	,	
						input	logic [25:0]	l	);
		opCode	= `hfsend	;
		dest	= 5'b0		;
		left	= 5'b0		;
		value	= 16'b10010	;	
		endLine				;
		opCode	= `hssend		;
		{dest, left, value}	= d	;
		endLine					;
		opCode	= `hssend		;
		{dest, left, value}	= l	;
		endLine	                ;		
	endfunction
	
	// pseudo-random square matrix generation
	function hPRANDOM(	input	logic [25:0]	d	);
		opCode	= `hfsend	;
		dest	= 5'b0		;
		left	= 5'b0		;
		value	= 16'b10011	;	
		endLine				;
		opCode	= `hssend		;
		{dest, left, value}	= d	;
		endLine					;
	endfunction
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	