// in CONTROLLER
	// acc <= value
	function cVLOAD(input logic [23:0] value);																				
		cOpCode 	= `cload;							
		cOperand 	= `imm	;
		cScalar		= value	;
	endfunction
	
	// acc <= {acc[23:0], value[7:0]}
	function cINSVAL(input logic [23:0] value);
		cOpCode 	= `cinsval	;
		cOperand 	= `cri		;
		cScalar		= value		;	
	endfunction
	
	// acc <= mem[value]
	function cLOAD(input logic [23:0] value);
		cOpCode 	= `cload;
		cOperand 	= `dir	;
		cScalar		= value	;
	endfunction
	
	// acc <= mem[addr + value]
	function cRLOAD(input logic [23:0] value);
		cOpCode 	= `cload;
		cOperand 	= `rel	;
		cScalar		= value	;	
	endfunction
	
	// acc <= mem[addr + value]; addr <= addr + value
	function cRILOAD(input logic [23:0] value);
		cOpCode 	= `cload;
		cOperand 	= `rei	;
		cScalar		= value	;
	endfunction
	
	// co-operand (redOut) load
	function cCLOAD; 
		cOpCode 	= `cload	;
		cOperand 	= `cim		;
		cScalar		= 24'b0		;
	endfunction
	
//in ARRAY
	// acc[i] <= i
	function IXLOAD;                             
		aOpCode 	= `contr			;       
		aOperand 	= `imm				;       
		aScalar		= {`ixload, 19'b0}	;       
		endLineA						;
	endfunction
	
	// acc[i] <= serialReg[i]
	function GETSR; 
		aOpCode 	= `contr			;
		aOperand 	= `imm				;
		aScalar		= {`getsr, 19'b0}	;
		endLineA						;
	endfunction
	
	// acc[i] <= aScalar
	function VLOAD(input logic [23:0] value);
		
		begin 	aOpCode 	= `load;
				aOperand 	= `imm	;
				aScalar		= value	;
				endLineA			;
		end
	endfunction
	
	// acc[i] <= {acc[i][23:0], aScalar[7:0]}
	function INSVAL(input logic [23:0] value);
		aOpCode 	= `insval	;
		aOperand 	= `cri		;
		aScalar		= value		;
		endLineA				;
	endfunction
	
	// acc[i] <= mem[i][aScalar]
	function LOAD(input logic [23:0] value);
		aOpCode 	= `load;
		aOperand 	= `dir	;
		aScalar		= value	;
		endLineA			;
	endfunction
	
	// acc[i] <= mem[i][addr[i] + aScalar]
	function RLOAD(input logic [23:0] value);
		aOpCode 	= `load;
		aOperand 	= `rel	;
		aScalar		= value	;
		endLineA			;
	endfunction
	
	// acc[i] <= mem[i][addr[i] + aScalar]
	// addr[i] <= addr[i] + aScalar
	function RILOAD(input logic [23:0] value);
		aOpCode 	= `load;
		aOperand 	= `rei	;
		aScalar		= value	;
		endLineA			;
	endfunction
	
	// acc[i] <= acc
	function CLOAD; 
		aOpCode 	= `load;
		aOperand 	= `cim	;
		aScalar		= 24'b0	;
		endLineA			;
	endfunction
	
	// acc[i] <= mem[acc]
	function CALOAD; 	
		aOpCode 	= `load;
		aOperand 	= `cdr	;
		aScalar		= 24'b0 ;
		endLineA			;		                        
	endfunction
	
	// acc[i] <= mem[addr[i] + acc]
	function CRLOAD; 																	
		aOpCode 	= `load;		
		aOperand 	= `crl	;	
		aScalar		= 24'b0 ;
		endLineA			;		                        
	endfunction 
	
	// acc[i] <= mem[addr[i] + acc]; addr[i] <= addr[i] + acc 
	function CRILOAD; 																	
		aOpCode 	= `load;		
		aOperand 	= `cri	;	
		aScalar		= 24'b0	;
		endLineA			;		                               
	endfunction
	
	// aMem[value] <= ioReg[i]; ioRst
	function  GETIO(input logic [23:0] value);	
		aOpCode 	= `getio;
		aOperand 	= `dir	;
		aScalar		= value	;
		endLineA			;
	endfunction
	
	// aMem[value + arrayAddrReg] <= ioReg[i]; ioRst
	function RIGETIO(input logic [23:0] value);	
		aOpCode 	= `getio;
		aOperand 	= `rei	;
		aScalar		= value	;
		endLineA			;
	endfunction
		
	
