// in CONTROLLER
	// immediate multiplication: acc <= acc * cScalar
	function cVMULT(input logic [23:0] value);	
		cOpCode 	= `cmult;
		cOperand 	= `imm	;
		cScalar		= value	;
	endfunction
	
	// immediate addressing multiplication: 
	// acc <= acc * mem[cScalar[s-1:0]] 
	function cMULT(input logic [9:0] value);	
		cOpCode 	= `cmult;
		cOperand 	= `dir	;
		cScalar		= value	;
	endfunction
	
	// relative addressing multiplication: 
	// acc <= acc * mem[addr + cScalar[s-1:0]]
	function cRMULT(input logic [9:0] value);	
		cOpCode 	= `cmult;
		cOperand 	= `rel	;
		cScalar		= value	;
	endfunction
	
	// relative addressing multiplication with address update: 
	// acc <= acc * mem[addr + cScalar[s-1:0]]
	// addr = addr + cScalar[s-1:0]
	function cRIMULT(input logic [9:0] value);	
		cOpCode 	= `cmult;
		cOperand 	= `rei	;
		cScalar		= value	;
	endfunction
	
	// cooperand addressing multiplication:
	// acc <= acc * coOperand
	function cCMULT(input logic [9:0] value);
		cOpCode 	= `cmult;
		cOperand 	= `cim	;
		cScalar		= value	;
	endfunction
	
// in ARRAY
	// value multiplication: acc[i] <= acc[i] * aScalar
	function VMULT(input logic [23:0] value);	
		aOpCode 	= `mult	;
		aOperand 	= `imm	;
		aScalar		= value	;
		endLineA			;
	endfunction
	
	// absolute multiplication
	// acc[i] <= acc[i] * vectMem[i][aScalar]
	function MULT(input logic [9:0] value);	
		aOpCode 	= `mult	;
		aOperand 	= `dir	;
		aScalar		= value	;
		endLineA			;
	endfunction
	
	// relative multiplication: 
	// acc[i] <= acc[i] * vectMem[i][addrVect[i] + aScalar[v-1:0]]
	function RMULT(input logic [23:0] value);
		aOpCode 	= `mult	;
		aOperand 	= `rel	;
		aScalar		= value	;
		endLineA			;
	endfunction
	
	// relative multiplication and increment: 
	// acc[i] <= acc[i] * vectMem[i][addrVect[i] + aScalar[v-1:0]]
	// addrVect[i] <= addrVect[i] + aScalar[v-1:0]
	function RIMULT(input logic [23:0] value);	
		aOpCode 	= `mult	;
		aOperand 	= `rei	;
		aScalar		= value	;
		endLineA			;
	endfunction
	
	// co-operand multiplication: 
	// acc[i] <= acc[i] * acc
	function CMULT; 
		aOpCode 	= `mult	;
		aOperand 	= `cim	;
		aScalar		= 24'b0	;
		endLineA			;
	endfunction
	
	// co-operand absolute multiplication
	// acc[i] <= acc[i] * vectMem[i][acc[v-1:0]]
	function CAMULT; 	
		aOpCode 	= `mult	;
		aOperand 	= `cdr	;
		aScalar		= 24'b0	;
		endLineA			;
	endfunction
	
	// co-operand relative multiplication: 
	// acc[i] <= acc[i] * vectMem[i][addrVect[i] + acc[v-1:0]]
	function CRMULT; 	
		aOpCode 	= `mult	;
		aOperand 	= `crl	;
		aScalar		= 24'b0	;
		endLineA			;
	endfunction	
	
	// co-operand relative multiplication & update addr: 
	// acc[i] <= acc[i] * vectMem[i][addrVect[i] + acc[v-1:0]]
	// addrVect[i] <= addrVect[i] + acc[v-1:0]
	function CRIMULT; 		
		aOpCode 	= `mult	;
		aOperand 	= `cri	;
		aScalar		= 24'b0	;
		endLineA			;
	endfunction