// in CONTROLLER
	// immediate OR-ing: acc <= acc | cScalar
	function cVOR(input logic [23:0] value);	
		cOpCode 	= `cbwor;
		cOperand 	= `imm	;
		cScalar		= value	;
	endfunction
	
	// immediate addressing OR-ing: 
	// acc <= acc | mem[cScalar[s-1:0]]
	function cOR(input logic [9:0] value);	
		cOpCode 	= `cbwor;
		cOperand 	= `dir	;
		cScalar		= value	;
	endfunction
	
	// relative addressing OR-ing: 
	// acc <= acc | mem[addr + cScalar[s-1:0]]
	function cROR(input logic [9:0] value);	
		cOpCode 	= `cbwor;
		cOperand 	= `rel	;
		cScalar		= value	;
	endfunction
	
	// relative addressing OR-ing with address update: 
	// acc <= acc | mem[addr + cScalar[s-1:0]]
	// addr = addr + cScalar[s-1:0]
	function cRIOR(input logic [9:0] value);	
		cOpCode 	= `cbwor;
		cOperand 	= `rei	;
		cScalar		= value	;
	endfunction
	
	// cooperand addressing OR-ing: acc <= acc | coOperand
	function cCOR(input logic [9:0] value);	
		cOpCode 	= `cbwor;
		cOperand 	= `cim	;
		cScalar		= value	;
	endfunction

// in ARRAY
	// value OR-ing: acc[i] <= acc[i] | aScalar
	function VOR(input logic [23:0] value);	
		aOpCode 	= `bwor	;
		aOperand 	= `imm	;
		aScalar		= value	;
		endLineA			;
	endfunction
	
	// absolute OR-ing
	// acc[i] <= acc[i] | vectMem[i][aScalar]
	function OR(input logic [23:0] value);	
		aOpCode 	= `bwor	;
		aOperand 	= `dir	;
		aScalar		= value	;
		endLineA			;
	endfunction
	
	// relative OR-ing: 
	// acc[i] <= acc[i] | vectMem[i][addrVect[i] + aScalar[v-1:0]]
	function ROR(input logic [23:0] value);	
		aOpCode 	= `bwor	;
		aOperand 	= `rel	;
		aScalar		= value	;
		endLineA			;
	endfunction
	
	// relative OR-ing and increment: 
	// acc[i] <= acc[i] | vectMem[i][addrVect[i] + aScalar[v-1:0]]
	//addrVect[i] <= addrVect[i] + aScalar[v-1:0]
	function RIOR(input logic [23:0] value);	
		aOpCode 	= `bwor	;
		aOperand 	= `rei	;
		aScalar		= value	;
		endLineA			;
	endfunction
	
	// co-operand OR-ing: acc[i] <= acc[i] | acc
	function COR; 
		aOpCode 	= `bwor	;
		aOperand 	= `cim	;
		aScalar		= 24'b0	;
		endLineA			;
	endfunction
	
	// co-operand absolute OR-ing
	// acc[i] <= acc[i] | vectMem[i][acc[v-1:0]]
	function CAOR; 	
		aOpCode 	= `bwor	;
		aOperand 	= `cdr	;
		aScalar		= 24'b0	;
		endLineA			;
	endfunction
	
	// co-operand relative OR-ing: 
	// acc[i] <= acc[i] | vectMem[i][addrVect[i] + acc[v-1:0]]
	function CROR; 	
		aOpCode 	= `bwor	;
		aOperand 	= `crl	;
		aScalar		= 24'b0	;
		endLineA			;	
	endfunction	
	
	// co-operand relative OR-ing & update addr: 
	// acc[i] <= acc[i] | vectMem[i][addrVect[i] + acc[v-1:0]]
	// addrVect[i] <= addrVect[i] + acc[v-1:0]
	function CRIOR; 
		aOpCode 	= `bwor	;
		aOperand 	= `cri	;
		aScalar		= 24'b0	;
		endLineA			;
	endfunction	