// in CONTROLLER
	// immediate subtract: acc <= acc - cScalar
	function cVSUB(input logic [23:0] value);	
		cOpCode 	= `csub	;
		cOperand	= `imm	;
		cScalar		= value	;
	endfunction
	
	// immediate addressing subtract: 
	// acc <= acc - mem[cScalar[9:0]]
	function cSUB(input logic [9:0] value);	
		cOpCode 	= `csub	;
		cOperand 	= `dir	;
		cScalar		= value	;
	endfunction
	
	// relative addressing subtract: 
	// acc <= acc - mem[addr + cScalar[9:0]]
	function cRSUB(input logic [9:0] value);	
		cOpCode 	= `csub	;
		cOperand 	= `rel	;
		cScalar		= value	;
	endfunction
	
	// relative addressing subtract with address update: 
	// acc <= acc - mem[addr + cScalar[9:0]]
	// addr = addr + cScalar[s-1:0]
	function cRISUB(input logic [9:0] value);
		cOpCode 	= `csub	;
		cOperand 	= `rei	;
		cScalar		= value	;
	endfunction
	
	// cooperand addressing subtract:
	// acc <= acc - coOperand
	function cCSUB;	
		cOpCode 	= `csub	;
		cOperand 	= `cim	;
		cScalar		= 24'b0	;
	endfunction


// in ARRAY
	// value subtract: acc[i] <= acc[i] - aScalar
	function VSUB(input logic [23:0] value);	
		aOpCode 	= `sub	;
		aOperand 	= `imm	;
		aScalar		= value	;
		endLineA			;
	endfunction
	
	// absolute subtract
	// acc[i] <= acc[i] - vectMem[i][aScalar]
	function SUB(input logic [23:0] value);	
		aOpCode 	= `sub	;
		aOperand 	= `dir	;
		aScalar		= value	;
		endLineA			;
	endfunction
	
	// relative subtract: 
	// acc[i] <= acc[i] - vectMem[i][addrVect[i] + aScalar[v-1:0]]
	function RSUB(input logic [23:0] value);	
		aOpCode 	= `sub	;
		aOperand 	= `rel	;
		aScalar		= value	;
		endLineA			;
	endfunction
	
	// relative subtract and increment: 
	// acc[i] <= acc[i] - vectMem[i][addrVect[i] + aScalar[v-1:0]]
	// addrVect[i] <= addrVect[i] + aScalar[v-1:0]
	function RISUB(input logic [23:0] value);	
		aOpCode 	= `sub	;
		aOperand 	= `rei	;
		aScalar		= value	;
		endLineA			;
	endfunction
	
	// co-operand subtract: acc[i] <= acc[i] - acc
	function CSUB; 
		aOpCode 	= `sub	;
		aOperand 	= `cim	;
		aScalar		= 24'b0	;
		endLineA			;
	endfunction
	
	// co-operand absolute subtract
	// acc[i] <= acc[i] - vectMem[i][acc[v-1:0]]
	function CASUB; 	
		aOpCode 	= `sub	;
		aOperand 	= `cdr	;
		aScalar		= 24'b0	;
		endLineA			;
	endfunction
	
	// co-operand relative subtract: 
	// acc[i] <= acc[i] - vectMem[i][addrVect[i] + acc[v-1:0]]
	function CRSUB; 	
		aOpCode 	= `sub	;
		aOperand 	= `crl	;
		aScalar		= 24'b0	;
		endLineA			;
	endfunction

	// co-operand relative subtract & addr update: 
	// acc[i] <= acc[i] - vectMem[i][addrVect[i] + acc[v-1:0]]
	// addrVect[i] <= addrVect[i] + acc[v-1:0]
	function CRISUB; 	
		aOpCode 	= `sub	;
		aOperand 	= `cri	;
		aScalar		= 24'b0	;
		endLineA			;
	endfunction		