// in CONTROLLER
	// immediate subtract with carry:
	// acc <= acc - cScalar - carry
	function cVSUBC(input logic [23:0] value);
		cOpCode 	= `csubcr	;
		cOperand 	= `imm		;
		cScalar		= value		;
	endfunction
	
	// immediate addressing subtract with carry: 
	// acc <= acc - mem[cScalar[9:0]] - carry 
	function cSUBC(input logic [9:0] value);	
		cOpCode 	= `csubcr	;
		cOperand 	= `dir		;
		cScalar		= value		;
	endfunction

	// relative addressing subtract with carry: 
	// acc <= acc - mem[addr + cScalar[9:0]] - carry
	function cRSUBC(input logic [9:0] value);	
		cOpCode 	= `csubcr	;
		cOperand 	= `rel		;
		cScalar		= value		;
	endfunction
	
	// relative addressing subtract with carry with address update: 
	// acc <= acc - mem[addr + cScalar[9:0]] - carry
	// addr = addr + cScalar[s-1:0]
	function cRISUBC(input logic [9:0] value);	
		cOpCode 	= `csubcr	;
		cOperand 	= `rei		;
		cScalar		= value		;
	endfunction
	
	// cooperand addressing subtract with carry:
	// acc <= acc - coOperand - carry
	function cCSUBC;	
		cOpCode 	= `csubcr	;
		cOperand 	= `cim		;
		cScalar		= 24'b0		;
	endfunction
	
// in ARRAY
	// value subtract with carry: 
	// acc[i] <= acc[i] - aScalar - carry
	function VSUBC(input logic [23:0] value);	
		aOpCode 	= `subcr;
		aOperand 	= `imm	;
		aScalar		= value	;
		endLineA			;
	endfunction
	
	// absolute subtract with carry
	// acc[i] <= acc[i] - vectMem[i][aScalar] - carry
	function SUBC(input logic [23:0] value);	
		aOpCode 	= `subcr;
		aOperand 	= `dir	;
		aScalar		= value	;
		endLineA			;
	endfunction
	
	// relative subtract with carry: 
	// acc[i] <= acc[i] - vectMem[i][addrVect[i] + aScalar[v-1:0]] - carry
	function RSUBC(input logic [23:0] value);	
		aOpCode 	= `subcr;
		aOperand 	= `rel	;
		aScalar		= value	;
		endLineA			;
	endfunction
	
	// relative subtract with carry and increment: 
	// acc[i] <= acc[i] - vectMem[i][addrVect[i] + aScalar[v-1:0]] - carry
	// addrVect[i] <= addrVect[i] + aScalar[v-1:0]
	function RISUBC(input logic [23:0] value);
		aOpCode 	= `subcr;
		aOperand 	= `rei	;
		aScalar		= value	;
		endLineA			;
	endfunction
	
	// co-operand subtract with carry: 
	// acc[i] <= acc[i] - acc - carry
	function CSUBC; 
		aOpCode 	= `subcr;
		aOperand 	= `cim	;
		aScalar		= 24'b0	;
		endLineA			;
	endfunction
	
	// co-operand absolute subtract with carry
	// acc[i] <= acc[i] - vectMem[i][acc[v-1:0]] - carry
	function CASUBC; 	
		aOpCode 	= `subcr;
		aOperand 	= `cdr	;
		aScalar		= 24'b0	;
		endLineA			;
	endfunction
	
	// co-operand relative subtract with carry: 
	// acc[i] <= acc[i] - vectMem[i][addrVect[i] + acc[v-1:0]] - carry
	function CRSUBC; 
		aOpCode 	= `subcr;
		aOperand 	= `crl	;
		aScalar		= 24'b0	;
		endLineA			;

	endfunction	
	
	// co-operand relative subtract with carry & update addr: 
	// acc[i] <= acc[i] - vectMem[i][addrVect[i] + acc[v-1:0]] - carry
	// addrVect[i] <= addrVect[i] + acc[v-1:0]
	function CRISUBC;   
		aOpCode 	= `subcr;
		aOperand 	= `cri	;
		aScalar		= 24'b0	;
		endLineA			;
	endfunction