// in CONTROLLER
	// immediate XOR-ing: acc <= acc ^ cScalar
	function cVXOR(input logic [23:0] value);	
		cOpCode 	= `cbwxor	;
		cOperand 	= `imm		;
		cScalar		= value		;
	endfunction
	
	// immediate addressing XOR-ing: 
	// acc <= acc ^ mem[cScalar[s-1:0]]
	function cXOR(input logic [9:0] value);	
		cOpCode 	= `cbwxor	;
		cOperand 	= `dir		;
		cScalar		= value		;
	endfunction
	
	// relative addressing XOR-ing: 
	// acc <= acc ^ mem[addr + cScalar[s-1:0]]
	function cRXOR(input logic [9:0] value);	
		cOpCode 	= `cbwxor	;
		cOperand 	= `rel		;
		cScalar		= value		;
	endfunction
	
	// relative addressing XOR-ing with address update: 
	// acc <= acc ^ mem[addr + cScalar[s-1:0]]
	// addr = addr + cScalar[s-1:0]
	function cRIXOR(input logic [9:0] value);	
		cOpCode 	= `cbwxor	;
		cOperand 	= `rei		;
		cScalar		= value		;
	endfunction
	
	// cooperand addressing XOR-ing:
	// acc <= acc ^ coOperandadditi
	function cCXOR(input logic [9:0] value);	
		cOpCode 	= `cbwxor	;
		cOperand 	= `cim		;
		cScalar		= 24'b0		;
	endfunction

// in ARRAY
	// value XOR-ing: acc[i] <= acc[i] ^ aScalar
	function VXOR(input logic [23:0] value)	;	
		aOpCode 	= `bwxor;
		aOperand 	= `imm	;
		aScalar		= value	;
		endLineA			;
	endfunction
	
	// absolute XOR-ing
	// acc[i] <= acc[i] ^ vectMem[i][aScalar]
	function XOR(input logic [23:0] value);	
		aOpCode 	= `bwxor;
		aOperand 	= `dir	;
		aScalar		= value	;
		endLineA			;
	endfunction
	
	// relative XOR-ing: 
	// acc[i] <= acc[i] ^ vectMem[i][addrVect[i] + aScalar[v-1:0]]
	function RXOR(input logic [23:0] value);	
		aOpCode 	= `bwxor;
		aOperand 	= `rel	;
		aScalar		= value	;
		endLineA			;
	endfunction
	
	// relative XOR-ing and increment: 
	// acc[i] <= acc[i] ^ vectMem[i][addrVect[i] + aScalar[v-1:0]]
	// addrVect[i] <= addrVect[i] + aScalar[v-1:0]
	function RIXOR(input logic [23:0] value);	
		aOpCode 	= `bwxor;
		aOperand 	= `rei	;
		aScalar		= value	;
		endLineA			;	
	endfunction
	
	// co-operand XOR-ing: acc[i] <= acc[i] ^ acc
	function CXOR; 
		aOpCode 	= `bwxor;
		aOperand 	= `cim	;
		aScalar		= 24'b0	;
		endLineA			;
	endfunction
	
	// co-operand absolute XOR-ing
	// acc[i] <= acc[i] ^ vectMem[i][acc[v-1:0]]
	function CAXOR; 	
		aOpCode 	= `bwxor;
		aOperand 	= `cdr	;
		aScalar		= 24'b0	;
		endLineA			;
	endfunction
	
	// co-operand relative XOR-ing: 
	// acc[i] <= acc[i] ^ vectMem[i][addrVect[i] + acc[v-1:0]]
	function CRXOR; 	
		aOpCode 	= `bwxor;
		aOperand 	= `crl	;
		aScalar		= 24'b0	;
		endLineA			;
	endfunction	
	
	// co-operand relative XOR-ing & update addr: 
	// acc[i] <= acc[i] ^ vectMem[i][addrVect[i] + acc[v-1:0]]
	// addrVect[i] <= addrVect[i] + aScalar[v-1:0]
	function CRIXOR; 	
		aOpCode 	= `bwxor;
		aOperand 	= `cri	;
		aScalar		= 24'b0	;
		endLineA			;
	endfunction